@@ -15,16 +15,19 @@
 namespace xs {
 
 struct my_perl_auto_t { // per-thread interpreter to help dealing with pTHX/aTHX, especially for static initialization
-    #ifdef PERL_IMPLICIT_CONTEXT
-    operator PerlInterpreter* () const { return PERL_GET_THX; }
-    PerlInterpreter* operator-> () const { return PERL_GET_THX; }
-    #endif
+  #ifdef PERL_IMPLICIT_CONTEXT
+    static PerlInterpreter* main_interp;
+    operator PerlInterpreter*   () const { return main_interp ? main_interp : PERL_GET_THX; }
+    PerlInterpreter* operator-> () const { return main_interp ? main_interp : PERL_GET_THX; }
+  #endif
 };
 extern my_perl_auto_t my_perl;
 
 void at_perl_destroy (const panda::function<void()>& f);
 
-void __call_at_perl_destroy ();
+void __call_at_perl_destroy  ();
+void __call_at_thread_create ();
+
 void __boot_module (const char* mod, void (*bootfunc)(pTHX_ CV*), const char* version, const char* file);
 
 }
